"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("./types");
const preset = {
    // https://docs.aws.amazon.com/de_de/AmazonCloudWatch/latest/events/ScheduledEvents.html
    presetId: 'default',
    useSeconds: false,
    useYears: true,
    useAliases: true,
    useBlankDay: true,
    allowOnlyOneBlankDayField: true,
    mustHaveBlankDayField: true,
    useLastDayOfMonth: true,
    useLastDayOfWeek: true,
    useNearestWeekday: true,
    useNthWeekdayOfMonth: true,
    seconds: {
        minValue: 0,
        maxValue: 59,
    },
    minutes: {
        minValue: 0,
        maxValue: 59,
    },
    hours: {
        minValue: 0,
        maxValue: 23,
    },
    daysOfMonth: {
        minValue: 1,
        maxValue: 31,
    },
    months: {
        minValue: 0,
        maxValue: 12,
    },
    daysOfWeek: {
        minValue: 1,
        maxValue: 7,
    },
    years: {
        minValue: 1970,
        maxValue: 2199,
    },
};
const options = Object.assign({ presetId: preset.presetId, preset }, {
    useSeconds: preset.useSeconds,
    useYears: preset.useYears,
    useAliases: preset.useAliases,
    useBlankDay: preset.useBlankDay,
    allowOnlyOneBlankDayField: preset.allowOnlyOneBlankDayField,
    mustHaveBlankDayField: preset.mustHaveBlankDayField,
    useLastDayOfMonth: preset.useLastDayOfMonth,
    useLastDayOfWeek: preset.useLastDayOfWeek,
    useNearestWeekday: preset.useNearestWeekday,
    useNthWeekdayOfMonth: preset.useNthWeekdayOfMonth,
    seconds: {
        lowerLimit: preset.seconds.minValue,
        upperLimit: preset.seconds.maxValue,
    },
    minutes: {
        lowerLimit: preset.minutes.minValue,
        upperLimit: preset.minutes.maxValue,
    },
    hours: {
        lowerLimit: preset.hours.minValue,
        upperLimit: preset.hours.maxValue,
    },
    daysOfMonth: {
        lowerLimit: preset.daysOfMonth.minValue,
        upperLimit: preset.daysOfMonth.maxValue,
    },
    months: {
        lowerLimit: preset.months.minValue,
        upperLimit: preset.months.maxValue,
    },
    daysOfWeek: {
        lowerLimit: preset.daysOfWeek.minValue,
        upperLimit: preset.daysOfWeek.maxValue,
    },
    years: {
        lowerLimit: preset.years.minValue,
        upperLimit: preset.years.maxValue,
    },
});
exports.default = options;
